#
# spec file for package difftastic
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2023 munix9@googlemail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           difftastic
Version:        0.57.0
Release:        1.1
Summary:        A structural diff that understands syntax
License:        Apache-2.0 AND MIT
URL:            https://difftastic.wilfred.me.uk/
Source0:        https://github.com/Wilfred/difftastic/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  c++_compiler
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  jq
BuildRequires:  mdbook
BuildRequires:  rust >= 1.63
BuildRequires:  shared-mime-info
Requires:       shared-mime-info
Suggests:       %{name}-doc
ExclusiveArch:  %{rust_tier1_arches}

%description
Difftastic is a structural diff tool that compares files based on their syntax.

%package doc
Summary:        Documentation for difftastic
BuildArch:      noarch

%description doc
This package contains the documentation for difftastic.

%prep
%autosetup -a1 -p1

%build
%{cargo_build}

cd manual
mdbook build

%install
#%%{cargo_install}
install -D -m 0755 -t %{buildroot}%{_bindir} target/release/difft

rm -v manual/book/.nojekyll
%fdupes -s manual/book

%check
%{cargo_test}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/difft

%files doc
%license LICENSE
%doc manual/book

%changelog
* Tue Apr  9 2024 Martin Schreiner <martin.schreiner@suse.com>
- 0.57.0:
  Parsing
  * Text file detection is now stricter, considering null bytes as a
    hint that files are binaries.
  Diffing
  * Fixed an issue where hidden files (filename starting with .) were
    ignored when diffing directories.
  * Scheme now uses the same slider heuristics as other lisps,
    preferring the outer delimiter.
  * Fixed an issue with line-based diffing where only the first line
    in a large changed region was highlighted. This was particularly
    noticeable when diffing brand new files.
  Display
  * Fixed an issue when reporting changes in binary files, where
    trailing whitespace was inconsistent with other changes shown.
* Sun Mar 24 2024 Gordon Leung <pirateclip@protonmail.com>
- 0.56.1:
  Parsing
  * Added support for Objective-C and VHDL.
  * Files starting with <?xml are now parsed as XML.
  * Fixed a munmap_chunk(): invalid pointer crash on parsing some large files,
  * particularly JSON.
  * Makefile*.in is now detected as Makefile syntax.
  * Improved shebang parsing with whitespace
  * Added support for Scheme and Smali.
  * 
  Diffing
  * Fixed an issue with runaway memory usage on text files with very long lines.
  Display
  * The default display width for tabs has changed to 4.
  * Fixed an issue where difftastic would sometimes output
    literal tabs rather than respecting the display width for tabs.
  * Fixed an issue where all files would show a permissions change
    when using difftastic with git difftool.
  * Fixed an issue with paths not showing the containing directory
    when using difftastic with git difftool.
  * Difftastic now correctly reports file permission changes when
    called from git diff.
  * Fixed an issue with the experimental JSON display mode where it
    ignored --skip-unchanged.
  * Fixed an issue with tabs not being replaced in single-column display.
* Mon Jan  8 2024 Andreas Stieger <andreas.stieger@gmx.de>
- 0.54.0:
  * Support reporting file permission changes
  * Support for Salesforce Apex, improve Clojure and Haskell
  * bug fixes
* Sun Nov 26 2023 Andreas Stieger <andreas.stieger@gmx.de>
- 0.53.1:
  * Parsing: Add support for SCSS,  Improve Kotlin support, and
    detect snap files (Jest snapshots) as JavaScript files
  * Fix an issue where adding or removing blank lines would be
    ignored by the textual diffing logic.
  * Directory diffing now respects .gitignore files.
  * New --sort-paths option for sorting files by path
  * New --strip-cr for improved diffing in mixed environment
  * The option --skip-unchanged now has a corresponding environment
    option DFT_SKIP_UNCHANGED
* Sun Oct 29 2023 Andreas Stieger <andreas.stieger@gmx.de>
- spec tweaks for submission
* Mon Oct  9 2023 munix9@googlemail.com
- update to version 0.52.0
